@@ -14,25 +14,25 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     CreateExperimentTemplateActionInputTypeDef,
-    CreateExperimentTemplateResponseResponseTypeDef,
+    CreateExperimentTemplateResponseTypeDef,
     CreateExperimentTemplateStopConditionInputTypeDef,
     CreateExperimentTemplateTargetInputTypeDef,
-    DeleteExperimentTemplateResponseResponseTypeDef,
-    GetActionResponseResponseTypeDef,
-    GetExperimentResponseResponseTypeDef,
-    GetExperimentTemplateResponseResponseTypeDef,
-    ListActionsResponseResponseTypeDef,
-    ListExperimentsResponseResponseTypeDef,
-    ListExperimentTemplatesResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
-    StartExperimentResponseResponseTypeDef,
-    StopExperimentResponseResponseTypeDef,
+    DeleteExperimentTemplateResponseTypeDef,
+    GetActionResponseTypeDef,
+    GetExperimentResponseTypeDef,
+    GetExperimentTemplateResponseTypeDef,
+    ListActionsResponseTypeDef,
+    ListExperimentsResponseTypeDef,
+    ListExperimentTemplatesResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    StartExperimentResponseTypeDef,
+    StopExperimentResponseTypeDef,
     UpdateExperimentTemplateActionInputItemTypeDef,
-    UpdateExperimentTemplateResponseResponseTypeDef,
+    UpdateExperimentTemplateResponseTypeDef,
     UpdateExperimentTemplateStopConditionInputTypeDef,
     UpdateExperimentTemplateTargetInputTypeDef,
 )
@@ -56,20 +56,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class FISClient:
+class FISClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        FISClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#can_paginate)
         """
 
@@ -83,21 +88,19 @@ class FISClient:
         roleArn: str,
         targets: Dict[str, "CreateExperimentTemplateTargetInputTypeDef"] = None,
         tags: Dict[str, str] = None
-    ) -> CreateExperimentTemplateResponseResponseTypeDef:
+    ) -> CreateExperimentTemplateResponseTypeDef:
         """
         Creates an experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.create_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.create_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#create_experiment_template)
         """
 
-    def delete_experiment_template(
-        self, *, id: str
-    ) -> DeleteExperimentTemplateResponseResponseTypeDef:
+    def delete_experiment_template(self, *, id: str) -> DeleteExperimentTemplateResponseTypeDef:
         """
         Deletes the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.delete_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.delete_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#delete_experiment_template)
         """
 
@@ -111,89 +114,87 @@ class FISClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#generate_presigned_url)
         """
 
-    def get_action(self, *, id: str) -> GetActionResponseResponseTypeDef:
+    def get_action(self, *, id: str) -> GetActionResponseTypeDef:
         """
         Gets information about the specified AWS FIS action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.get_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.get_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_action)
         """
 
-    def get_experiment(self, *, id: str) -> GetExperimentResponseResponseTypeDef:
+    def get_experiment(self, *, id: str) -> GetExperimentResponseTypeDef:
         """
         Gets information about the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.get_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.get_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment)
         """
 
-    def get_experiment_template(self, *, id: str) -> GetExperimentTemplateResponseResponseTypeDef:
+    def get_experiment_template(self, *, id: str) -> GetExperimentTemplateResponseTypeDef:
         """
         Gets information about the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.get_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.get_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment_template)
         """
 
     def list_actions(
         self, *, maxResults: int = None, nextToken: str = None
-    ) -> ListActionsResponseResponseTypeDef:
+    ) -> ListActionsResponseTypeDef:
         """
         Lists the available AWS FIS actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.list_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.list_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_actions)
         """
 
     def list_experiment_templates(
         self, *, maxResults: int = None, nextToken: str = None
-    ) -> ListExperimentTemplatesResponseResponseTypeDef:
+    ) -> ListExperimentTemplatesResponseTypeDef:
         """
         Lists your experiment templates.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.list_experiment_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.list_experiment_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiment_templates)
         """
 
     def list_experiments(
         self, *, maxResults: int = None, nextToken: str = None
-    ) -> ListExperimentsResponseResponseTypeDef:
+    ) -> ListExperimentsResponseTypeDef:
         """
         Lists your experiments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.list_experiments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.list_experiments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiments)
         """
 
-    def list_tags_for_resource(
-        self, *, resourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_tags_for_resource)
         """
 
     def start_experiment(
         self, *, clientToken: str, experimentTemplateId: str, tags: Dict[str, str] = None
-    ) -> StartExperimentResponseResponseTypeDef:
+    ) -> StartExperimentResponseTypeDef:
         """
         Starts running an experiment from the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.start_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.start_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#start_experiment)
         """
 
-    def stop_experiment(self, *, id: str) -> StopExperimentResponseResponseTypeDef:
+    def stop_experiment(self, *, id: str) -> StopExperimentResponseTypeDef:
         """
         Stops the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.stop_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.stop_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#stop_experiment)
         """
 
@@ -201,7 +202,7 @@ class FISClient:
         """
         Applies the specified tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#tag_resource)
         """
 
@@ -209,7 +210,7 @@ class FISClient:
         """
         Removes the specified tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#untag_resource)
         """
 
@@ -222,10 +223,10 @@ class FISClient:
         targets: Dict[str, "UpdateExperimentTemplateTargetInputTypeDef"] = None,
         actions: Dict[str, "UpdateExperimentTemplateActionInputItemTypeDef"] = None,
         roleArn: str = None
-    ) -> UpdateExperimentTemplateResponseResponseTypeDef:
+    ) -> UpdateExperimentTemplateResponseTypeDef:
         """
         Updates the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/fis.html#FIS.Client.update_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/fis.html#FIS.Client.update_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#update_experiment_template)
         """
